﻿using ELTE.TravelAgency.Data;
using ELTE.TravelAgency.Service.Models;
using System;
using System.Linq;
using System.Web.Http;

namespace ELTE.TravelAgency.Service.Controllers
{
    /// <summary>
    /// Városok lekérdezését biztosító vezérlő.
    /// </summary>
    public class CitiesController : ApiController
    {
        private ITravelAgencyEntities _entities;
        
        /// <summary>
        /// Vezérlő példányosítása.
        /// </summary>
        /// <param name="entities">Entitásmodell.</param>
        public CitiesController(ITravelAgencyEntities entities)
        {
            if (entities == null)
                throw new ArgumentNullException("entities");
            
            _entities = entities;
        }
        
        /// <summary>
        /// Vezérlő megsemmisítése.
        /// </summary>
        ~CitiesController()
        {
            Dispose(false);
        }

        /// <summary>
        /// Városok lekérdezése.
        /// </summary>
        public IHttpActionResult GetCities()
        {
            try
            {
                return Ok(_entities.City.ToList().Select(city => new CityDTO
                {
                    Id = city.Id,
                    Name = city.Name
                }));
            }
            catch
            {
                return InternalServerError();
            }
        }

        /// <summary>
        /// Megsemmisítés.
        /// </summary>
        protected override void Dispose(Boolean disposing)
        {
            if (disposing)
            {
                _entities.Dispose();
            }

            base.Dispose(disposing);
        }
    }
}
